Renders a template's SQL expression with specific parameter values, without creating a concept. Useful for previewing or ad-hoc evaluation.
Usage
ont_render_template(template_id, parameter_values = list(), con = NULL)Renders a template's SQL expression with specific parameter values, without creating a concept. Useful for previewing or ad-hoc evaluation.
ont_render_template(template_id, parameter_values = list(), con = NULL)